pub struct TrackerDAQEventPacket {
pub header: TelemetryPacketHeader,
pub daq_header: TrackerHeader,
pub events: Vec<TrackerDAQEvent>,
pub run_id: u16,
pub run_id_old: u8,
pub n_hits: u16,
}Expand description
Tracker stand-alone complete event information from up-to multiple DAQ boxes as used in TelemetryPacketType::Tracker (80)
Fields
header: TelemetryPacketHeaderdaq_header: TrackerHeaderevents: Vec<TrackerDAQEvent>run_id: u16run_id_old: u8n_hits: u16internal counter for number of tracker hits in this event
Implementations
Sourceimpl TrackerDAQEventPacket
impl TrackerDAQEventPacket
pub fn new() -> Self
Sourcepub fn emit_empty(&self) -> Self
pub fn emit_empty(&self) -> Self
Return an empty shell, that is all information except the actual events
Ben Drowned…
Sourcepub fn add_event(&mut self, ev: TrackerDAQEvent)
pub fn add_event(&mut self, ev: TrackerDAQEvent)
Adds a TrackerDAQEvent
Sourcepub fn clear_events(&mut self)
pub fn clear_events(&mut self)
Remove all the TrackerDAQEvents in the event list
Sourcepub fn pack(&self) -> TelemetryPacket
pub fn pack(&self) -> TelemetryPacket
Create a telemetrypacket
Sourcepub fn remove_event(&mut self, evid: u32)
pub fn remove_event(&mut self, evid: u32)
Remove a single TrackerDAQEvent from the associated list of events
Arguments:
- evid : Event ID of the event in the list of associated events to be removed
Sourcepub fn get_hits(&self) -> Vec<TrackerHit>
pub fn get_hits(&self) -> Vec<TrackerHit>
Get all hits from all daq boxes participating in this event
Sourcepub fn get_event_ids(&self) -> Vec<u32>
pub fn get_event_ids(&self) -> Vec<u32>
Get all event ids in the packet (these might be different)
Sourcepub fn get_event_for_evid(&self, evid: u32) -> Option<TrackerDAQEvent>
pub fn get_event_for_evid(&self, evid: u32) -> Option<TrackerDAQEvent>
Get a copy specific TrackerDAQEvent for a given event id
Sourcepub fn get_hits_for_evid(&self, evid: u32) -> Vec<TrackerHit>
pub fn get_hits_for_evid(&self, evid: u32) -> Vec<TrackerHit>
Return all tracker hits which belong to a certain event id
pub fn from_telemetrypacket( packet: &TelemetryPacket, ) -> Result<Self, SerializationError>